Learn R Programming

flair (version 0.0.2)

decorate: Builds a with_flair object from either a code chunk or a string object containing source code.

Description

decorate does its best to guess if it has been given a code string or a chunk name, based on the presence of special characters.

Usage

decorate(x, ...)

Arguments

x

A string, containing either a chunk label or R code.

...

Chunk options to pass along

Value

A with_flair object.

See Also

decorate_chunk, decorate_code