Learn R Programming

flair (version 0.0.2)

flair-package: A package for adding flair to your displayed source code.

Description

This package provides ...

Arguments

Flair functions

The flair_* functions add decorative formatting to source code.

Decorate functions

The decorate functions execute source code and simultaneously prepare it to have flair added, to display when knitted.