Learn R Programming

flair (version 0.0.2)

print.with_flair: When run interactively, a with_flair object should preview the flaired source code in the viewer pane. (Only if in RStudio.)

Description

When run interactively, a with_flair object should preview the flaired source code in the viewer pane. (Only if in RStudio.)

Usage

# S3 method for with_flair
print(x, ...)

Arguments

x

A with_flair object.

...

Other print options

Value

None