The main use case for split_sandwiches() is for html editing: You might want to separate the original text from the html tags, make certain edits to the text only, and then re-wrap the tags.
This is different from str_split() or similar, because the delimiters are preserved and remain attached to a section.
Note that split_sandwiches() is not vectorized (sorry). It only takes a single character object.