powered by
with_flair
decorate does its best to guess if it has been given a code string or a chunk name, based on the presence of special characters.
decorate
decorate(x, ...)
A string, containing either a chunk label or R code.
Chunk options to pass along
A with_flair object.
decorate_chunk, decorate_code
decorate_chunk
decorate_code