powered by
flair_lines returns a string with formatting wrappers(currently only html), or applies the formatting to the source elements of a with_flair object.
flair_lines
with_flair
flair_lines(x, lines)# S3 method for default flair_lines(x, lines)
# S3 method for default flair_lines(x, lines)
A string or with_flair object
Integer vector indicating which lines to apply the flair styling to.
A string with formatting wrappers.
# NOT RUN { code_string <- "x <- mean(1:10, na.rm = TRUE) sqrt(x)" %>% flair_lines(2) # }
Run the code above in your browser using DataLab